pub enum FlashError {
InvalidAddress,
AccessViolation,
NeedsErase,
}Expand description
Flash controller errors.
Variants
InvalidAddress
The target address or page to write or erase is invalid.
AccessViolation
The flash controller was busy or locked when attempting to write or erase.
NeedsErase
Writing over the old data with new data would cause 0 -> 1 bit transitions. The target address must be erased before writing new data.